@@ -283,23 +283,22 @@ class ImageCrop:
                     min_bottom_ratio = self.__divide(slot_height - interest_top, (1 - y1) * img.height)
 
                     if left == 0.5 and right == 0.5:  # 图片能放在slot位内 human 会被裁掉
-                        min_img_left_ratio = self.__divide(0.5 * img.width, interest_left + interest_width / 2)
-                        min_img_right_ratio = self.__divide(0.5 * img.width, slot_width-interest_left-interest_width/2)
+                        min_img_left_ratio = self.__divide(interest_left + interest_width / 2, 0.5 * img.width)
+                        min_img_right_ratio = self.__divide(slot_width-interest_left-interest_width/2, 0.5 * img.width)
 
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_img_left_ratio, min_img_right_ratio)
                         # 换算 回 原图的x
                         x = ((interest_left + interest_width / 2) * max_ratio) / slot_width
 
                     else:  # human 放在 兴趣区域内
-                        min_human_left_ratio = self.__divide(interest_left, left * img.width)
+                        min_human_left_ratio = self.__divide(interest_left + interest_width / 2, x_center * img.width)
 
-                        min_human_right_ratio = self.__divide(slot_width-interest_left-interest_width, (1 - right)*img.width)
+                        min_human_right_ratio = self.__divide(slot_width-interest_left-interest_width/2, (1 - x_center)*img.width)
 
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_human_left_ratio, min_human_right_ratio)
 
                         # 换算 回 原图的x
-                        x = ((interest_left + interest_width / 2) * max_ratio - (
-                                    (right - left) / 2 * img.width)) / slot_width
+                        x = (x_center * img.width - (interest_left + interest_width / 2) / max_ratio) / slot_width
 
                     y = y1
                     scale_x = scale_y = max_ratio
